==> hoteldruid-mod-sv_2.1.2-1.tar.gz: sv/modifica_var_contr.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Variabili personalizzate dei documenti":  $messaggio = "Valfria dokumentvariabler"; break;
case "Variabili personalizzate":  		$messaggio = "Valfria variabler"; break;
case "Elimina":  				$messaggio = "Ta bort"; break;
case "Aggiungi":  				$messaggio = "L&auml;gg till"; break;
case "se":  					$messaggio = "if"; break;
case "è uguale a":  				$messaggio = "&auml;r lika med"; break;
case "è diverso da":  				$messaggio = "&auml;r skiljd fr&aring;n"; break;
case "allora porre":  				$messaggio = "s&aring; s&auml;tt"; break;
case "uguale a":  				$messaggio = "lika med"; break;
case "Nuova variabile personalizzata inserita":	$messaggio = "Ny valfri variabel infogad"; break;
case "I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "Infogade data &auml;r <div style=\"display: inline; color: red;\">felaktiga</div>"; break;
case "Variabile personalizzata eliminata":  	$messaggio = "Valfri variabel borttagen"; break;
case "Nuova condizione inserita":  		$messaggio = "Nytt villkor infogat"; break;
case "Condizione eliminata":  			$messaggio = "Villkor borttaget"; break;
case "porre":  					$messaggio = "put"; break;
case "sostituendo":  				$messaggio = "ers&auml;ttande"; break;
case "con":  					$messaggio = "med"; break;
case "arrotondato a":  				$messaggio = "avrundat till"; break;
case "e":  					$messaggio = "och"; break;
case "o":  					$messaggio = "eller"; break;
case "concatenato con":  				$messaggio = "konkatenerad med"; break;
case "allora":  				$messaggio = "s&aring;"; break;
case "uguaglia":  				$messaggio = "likst&auml;ll"; break;
case "concatena":  				$messaggio = "konkatenera"; break;
case "dopo":  					$messaggio = "efter"; break;
case "caratteri":  				$messaggio = "bokst&auml;ver"; break;
case "se mancanti riempire con":  		$messaggio = "om de saknas, fyll dom med"; break;
case "la parte":  				$messaggio = "vid"; break;
case "finale":  				$messaggio = "slutet"; break;
case "iniziale":  				$messaggio = "b&ouml;rjan"; break;
case "riempiendo i mancanti con":  		$messaggio = "fyll i f&ouml;r de saknade med"; break;
case "all'inizio":  				$messaggio = "i b&ouml;rjan"; break;
case "alla fine":  				$messaggio = "vid slutet"; break;
case "Array personalizzati":  			$messaggio = "Valfria arrayer"; break;
case "Array della variabile":  			$messaggio = "Variabelarray"; break;
case "Valori iniziali da assegnare all'array":	$messaggio = "Ursprungliga v&auml;rden att tilldelas arrayen"; break;
case "Nessun valore predefinito":  		$messaggio = "Inga ursprungliga v&auml;rden"; break;
case "separati da virgole":  			$messaggio = "separerade med komman"; break;
case "nelle ripetizioni vengono considerate solo le prenotazioni nella data valutata":	$messaggio = "i repetitioner betraktas endast bokningar p&aring; betraktat datum"; break;
case "<b>Condizioni</b> applicate":  		$messaggio = "<b>Villkor</b> till&auml;mpade"; break;
case "a tutti i documenti":  			$messaggio = "f&ouml;r alla dokument"; break;
case "al documento":  				$messaggio = "f&ouml;r dokumentet"; break;
case "Modifica le condizioni applicate":  	$messaggio = "&Auml;ndra till&auml;mpade villkor"; break;
case "Modifica":  				$messaggio = "&Auml;ndra"; break;
case "Array personalizzato eliminato":  	$messaggio = "Valfri array borttagen"; break;
case "Nuovo array personalizzato inserito":  	$messaggio = "Ny valfri array infogad"; break;
case "azzera l'array":  			$messaggio = "icke-inst&auml;lld array"; break;
case "non processare le condizioni successive":	$messaggio = "utv&auml;rdera inte senare villkor"; break;
case "è maggiore di":  				$messaggio = "&auml;r st&ouml;rre &auml;n"; break;
case "è minore di":  				$messaggio = "&auml;r mindre &auml;n"; break;
case "solo al documento":  			$messaggio = "bara f&ouml;r dokumentet"; break;
case "solo all'inizio delle ripetizioni delle prenotazioni":	$messaggio = "bara n&auml;r bokningsrepetitioner startas"; break;
case "in tutte le ripetizioni delle prenotazioni":	$messaggio = "i alla bokningsrepetitioner"; break;
case "azzera l'array":  			$messaggio = "icke-inst&auml;lld array"; break;
case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione":	$messaggio = "Use a custom variable that ends with \"_p\" to add the thousands separators and 2 decimals after the operation"; break;
case "troncare":  				$messaggio = "truncate"; break;
case "valori progressivi tra le date selezionate":	$messaggio = "progressive values between selected dates"; break;
case "una lista di valori predefiniti":  	$messaggio = "a list of predefined values"; break;
case "Modifica il documento":  			$messaggio = "Modify document"; break;
case "nuova condizione":  			$messaggio = "new condtition"; break;
case "da applicare":  				$messaggio = "to be applied"; break;
case "solo all'inizio del documento":  		$messaggio = "only at the beginning of the document"; break;
case "sempre":  				$messaggio = "always"; break;
case "azione":  				$messaggio = "action"; break;
case "aggiungi un altro &quot;se&quot;":  	$messaggio = "add another &quot;if&quot;"; break;
case "assegna all'array":  			$messaggio = "assign to the array"; break;
case "aggiungi la nuova condizione":  		$messaggio = "add new condition"; break;
case "i valori":  				$messaggio = "the values"; break;
case "fino alla fine":  			$messaggio = "until the end"; break;
case "fino al prossimo &quot;riprendi&quot;":  	$messaggio = "until next &quot;resume&quot;"; break;
case "riprendi a processare le condizioni successive":	$messaggio = "resume evaluating the subsequent conditions"; break;
case "se precedentemente interrotte":  		$messaggio = "if previously interrupted"; break;
case "modifica la condizione":  		$messaggio = "modify condition"; break;
case "da applicare":  				$messaggio = "to be applied"; break;
case "condizione modificata":  			$messaggio = "condition modified"; break;
case "annulla":  				$messaggio = "cancel"; break;
case "Utilizza sempre":				$messaggio = "Always use"; break;
case "Importa ora":				$messaggio = "Import now"; break;
case "variabili e condizioni del documento":	$messaggio = "variables and conditions from document"; break;
case "le variabili e condizioni attuali verranno cancellate":	$messaggio = "current variables and coditions will be deleted"; break;
case "Visualizza le condizioni del documento":	$messaggio = "view conditions of document"; break;
case "il giorno":  				$messaggio = "the day"; break;
case "il mese":  				$messaggio = "the month"; break;
case "l'anno":  				$messaggio = "the year"; break;
case "il giorno della settimana":  		$messaggio = "the day of the week"; break;
case "della data":  				$messaggio = "from date"; break;
case "contiene":  				$messaggio = "contains"; break;
case "maiusc./minusc.":  			$messaggio = "case sensitive"; break;
case "la data":  				$messaggio = "the date"; break;
case "formato ISO":  				$messaggio = "ISO format"; break;
case "formato corrente":  			$messaggio = "current format"; break;
case "giorni":  				$messaggio = "days"; break;
case "mesi":  					$messaggio = "months"; break;
case "anni":  					$messaggio = "years"; break;
case "i valori dell'array":  			$messaggio = "the values from array"; break;
case "elimina questo &quot;se&quot;":  		$messaggio = "delete this &quot;if&quot;"; break;
case "valori progressivi tra il primo arrivo e l'ultima partenza":	$messaggio = "progressive values between first arrival and last departure"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_2.2.3-1.tar.gz: sv/modifica_var_contr.php <==
<?php

switch ($messaggio) {

case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Variabili personalizzate dei documenti":  $messaggio = "Valfria dokumentvariabler"; break;
case "Variabili personalizzate":  		$messaggio = "Valfria variabler"; break;
case "Elimina":  				$messaggio = "Ta bort"; break;
case "Aggiungi":  				$messaggio = "L&auml;gg till"; break;
case "se":  					$messaggio = "if"; break;
case "è uguale a":  				$messaggio = "&auml;r lika med"; break;
case "è diverso da":  				$messaggio = "&auml;r skiljd fr&aring;n"; break;
case "allora porre":  				$messaggio = "s&aring; s&auml;tt"; break;
case "uguale a":  				$messaggio = "lika med"; break;
case "Nuova variabile personalizzata inserita":	$messaggio = "Ny valfri variabel infogad"; break;
case "I dati inseriti sono <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "Infogade data &auml;r <div style=\"display: inline; color: red;\">felaktiga</div>"; break;
case "Variabile personalizzata eliminata":  	$messaggio = "Valfri variabel borttagen"; break;
case "Nuova condizione inserita":  		$messaggio = "Nytt villkor infogat"; break;
case "Condizione eliminata":  			$messaggio = "Villkor borttaget"; break;
case "porre":  					$messaggio = "put"; break;
case "sostituendo":  				$messaggio = "ers&auml;ttande"; break;
case "con":  					$messaggio = "med"; break;
case "arrotondato a":  				$messaggio = "avrundat till"; break;
case "e":  					$messaggio = "och"; break;
case "o":  					$messaggio = "eller"; break;
case "concatenato con":  				$messaggio = "konkatenerad med"; break;
case "allora":  				$messaggio = "s&aring;"; break;
case "uguaglia":  				$messaggio = "likst&auml;ll"; break;
case "concatena":  				$messaggio = "konkatenera"; break;
case "dopo":  					$messaggio = "efter"; break;
case "caratteri":  				$messaggio = "bokst&auml;ver"; break;
case "se mancanti riempire con":  		$messaggio = "om de saknas, fyll dom med"; break;
case "la parte":  				$messaggio = "vid"; break;
case "finale":  				$messaggio = "slutet"; break;
case "iniziale":  				$messaggio = "b&ouml;rjan"; break;
case "riempiendo i mancanti con":  		$messaggio = "fyll i f&ouml;r de saknade med"; break;
case "all'inizio":  				$messaggio = "i b&ouml;rjan"; break;
case "alla fine":  				$messaggio = "vid slutet"; break;
case "Array personalizzati":  			$messaggio = "Valfria arrayer"; break;
case "Array della variabile":  			$messaggio = "Variabelarray"; break;
case "Valori iniziali da assegnare all'array":	$messaggio = "Ursprungliga v&auml;rden att tilldelas arrayen"; break;
case "Nessun valore predefinito":  		$messaggio = "Inga ursprungliga v&auml;rden"; break;
case "separati da virgole":  			$messaggio = "separerade med komman"; break;
case "nelle ripetizioni vengono considerate solo le prenotazioni nella data valutata":	$messaggio = "i repetitioner betraktas endast bokningar p&aring; betraktat datum"; break;
case "<b>Condizioni</b> applicate":  		$messaggio = "<b>Villkor</b> till&auml;mpade"; break;
case "a tutti i documenti":  			$messaggio = "f&ouml;r alla dokument"; break;
case "al documento":  				$messaggio = "f&ouml;r dokumentet"; break;
case "Modifica le condizioni applicate":  	$messaggio = "&Auml;ndra till&auml;mpade villkor"; break;
case "Modifica":  				$messaggio = "&Auml;ndra"; break;
case "Array personalizzato eliminato":  	$messaggio = "Valfri array borttagen"; break;
case "Nuovo array personalizzato inserito":  	$messaggio = "Ny valfri array infogad"; break;
case "azzera l'array":  			$messaggio = "icke-inst&auml;lld array"; break;
case "non processare le condizioni successive":	$messaggio = "utv&auml;rdera inte senare villkor"; break;
case "è maggiore di":  				$messaggio = "&auml;r st&ouml;rre &auml;n"; break;
case "è minore di":  				$messaggio = "&auml;r mindre &auml;n"; break;
case "solo al documento":  			$messaggio = "bara f&ouml;r dokumentet"; break;
case "solo all'inizio delle ripetizioni delle prenotazioni":	$messaggio = "bara n&auml;r bokningsrepetitioner startas"; break;
case "in tutte le ripetizioni delle prenotazioni":	$messaggio = "i alla bokningsrepetitioner"; break;
case "azzera l'array":  			$messaggio = "icke-inst&auml;lld array"; break;
case "Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia e 2 decimali dopo l'operazione":	$messaggio = "Use a custom variable that ends with \"_p\" to add the thousands separators and 2 decimals after the operation"; break;
case "troncare":  				$messaggio = "truncate"; break;
case "valori progressivi tra le date selezionate":	$messaggio = "progressive values between selected dates"; break;
case "valori progressivi tra il primo arrivo e l'ultima partenza":	$messaggio = "progressive values between first arrival and last departure"; break;
case "una lista di valori predefiniti":  	$messaggio = "a list of predefined values"; break;
case "Modifica il documento":  			$messaggio = "Modify document"; break;
case "nuova condizione":  			$messaggio = "new condtition"; break;
case "da applicare":  				$messaggio = "to be applied"; break;
case "solo all'inizio del documento":  		$messaggio = "only at the beginning of the document"; break;
case "sempre":  				$messaggio = "always"; break;
case "azione":  				$messaggio = "action"; break;
case "aggiungi un altro &quot;se&quot;":  	$messaggio = "add another &quot;if&quot;"; break;
case "assegna all'array":  			$messaggio = "assign to the array"; break;
case "aggiungi la nuova condizione":  		$messaggio = "add new condition"; break;
case "i valori":  				$messaggio = "the values"; break;
case "fino alla fine":  			$messaggio = "until the end"; break;
case "fino al prossimo &quot;riprendi&quot;":  	$messaggio = "until next &quot;resume&quot;"; break;
case "riprendi a processare le condizioni successive":	$messaggio = "resume evaluating the subsequent conditions"; break;
case "se precedentemente interrotte":  		$messaggio = "if previously interrupted"; break;
case "modifica la condizione":  		$messaggio = "modify condition"; break;
case "da applicare":  				$messaggio = "to be applied"; break;
case "condizione modificata":  			$messaggio = "condition modified"; break;
case "annulla":  				$messaggio = "cancel"; break;
case "Utilizza sempre":				$messaggio = "Always use"; break;
case "Importa ora":				$messaggio = "Import now"; break;
case "variabili e condizioni del documento":	$messaggio = "variables and conditions from document"; break;
case "le variabili e condizioni attuali verranno cancellate":	$messaggio = "current variables and coditions will be deleted"; break;
case "Visualizza le condizioni del documento":	$messaggio = "view conditions of document"; break;
case "il giorno":  				$messaggio = "the day"; break;
case "il mese":  				$messaggio = "the month"; break;
case "l'anno":  				$messaggio = "the year"; break;
case "il giorno della settimana":  		$messaggio = "the day of the week"; break;
case "della data":  				$messaggio = "from date"; break;
case "contiene":  				$messaggio = "contains"; break;
case "maiusc./minusc.":  			$messaggio = "case sensitive"; break;
case "la data":  				$messaggio = "the date"; break;
case "formato ISO":  				$messaggio = "ISO format"; break;
case "formato corrente":  			$messaggio = "current format"; break;
case "giorni":  				$messaggio = "days"; break;
case "mesi":  					$messaggio = "months"; break;
case "anni":  					$messaggio = "years"; break;
case "i valori dell'array":  			$messaggio = "the values from array"; break;
case "elimina questo &quot;se&quot;":  		$messaggio = "delete this &quot;if&quot;"; break;
case "uguale al numero di":  			$messaggio = "equal to the number of"; break;
case "numero di":  				$messaggio = "the number of"; break;
case "dalla data":  				$messaggio = "from date"; break;
case "alla data":  				$messaggio = "to date"; break;
case "solo nelle ripetizioni degli ospiti":	$messaggio = "only inside repetitions of guests"; break;
case "solo nelle ripetizioni dei costi aggiuntivi":	$messaggio = "only inside repetitions of extra costs"; break;
case "solo nelle ripetizioni dei pagamenti":	$messaggio = "only inside repetitions of payments"; break;
case "solo nelle ripetizioni delle unità":	$messaggio = "only inside repetitions of units"; break;
case "Condizioni applicate":  			$messaggio = "Conditions applied"; break;
case "tutte le altre condizioni non verranno più applicate in queste ripetizioni":	$messaggio = "all other conditions won't be apllied anymore in these repetitions"; break;
case "solo nelle ripetizioni dell'array":	$messaggio = "only inside repetitions of array"; break;
case "prima di con valori negativi":  		$messaggio = "before with negative values"; break;
case "prima di":  				$messaggio = "before"; break;
case "in minuscole":  				$messaggio = "in lower case"; break;
case "in maiuscole":  				$messaggio = "in upper case"; break;
case "codificato per URL":  			$messaggio = "encoded for URL"; break;
case "codificato in ASCII":  			$messaggio = "encoded in ASCII"; break;
case "in ASCII esteso":  			$messaggio = "in extended ASCII"; break;
case "codificato con MD5":  			$messaggio = "encoded with MD5"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
